# Tutorials

```{toctree}
:maxdepth: 1

basic_usage.ipynb
sc_multi.ipynb
prior_knowledge.ipynb
bivariate.ipynb
sma.ipynb
misty.ipynb
targeted.ipynb
liana_c2c.ipynb
mofacellular.ipynb
mofatalk.ipynb
inflow_score.ipynb
```
